@@ -18,7 +18,7 @@ import {
     Provider,
     ProviderIconMap,
     ProviderLongTextMap,
-} from '@open-cluster-management/ui-components'
+} from '@stolostron/ui-components'
 import { PageSection } from '@patternfly/react-core'
 import _ from 'lodash'
 import { Fragment, useContext, useEffect, useState } from 'react'
