@@ -11,7 +11,7 @@ import {
     AcmTable,
     IAcmTableButtonAction,
     Provider,
-} from '@open-cluster-management/ui-components'
+} from '@stolostron/ui-components'
 import {
     ButtonVariant,
     Flex,
