@@ -26,7 +26,7 @@ import {
     AcmSubmit,
     AcmToastContext,
     Provider,
-} from '@open-cluster-management/ui-components'
+} from '@stolostron/ui-components'
 import {
     ActionGroup,
     ButtonVariant,
