@@ -1,7 +1,7 @@
 /* Copyright Contributors to the Open Cluster Management project */
 import React from 'react'
 import { Alert, AlertVariant, ButtonVariant } from '@patternfly/react-core'
-import { AcmButton } from '@open-cluster-management/ui-components'
+import { AcmButton } from '@stolostron/ui-components'
 import { Link } from 'react-router-dom'
 
 export type WarningContextType = { title: string; text: string; linkTo?: string; linkText?: string } | undefined
