@@ -14,6 +14,7 @@ import {
     getWorkerName,
     isHidden_lt_OCP48,
     isHidden_SNO,
+    onChangeConnection,
     onChangeSNO,
     addSnoText,
 } from './ControlDataHelpers'
@@ -616,6 +617,7 @@ const controlDataAWS = [
         },
         available: [],
         providerId: 'aws',
+        onSelect: onChangeConnection,
         prompts: CREATE_CLOUD_CONNECTION,
     },
     ...clusterDetailsControlData,
@@ -840,15 +842,6 @@ const awsPrivateControlData = [
         type: 'title',
         info: 'creation.aws.privateAWS.info',
     },
-    {
-        name: 'Hosted Zone',
-        tooltip: 'creation.aws.hostedZone.tooltip',
-        id: 'hostedZone',
-        type: 'text',
-        placeholder: 'creation.aws.hostedZone.placeholder',
-        active: '',
-        validation: VALIDATE_ALPHANUMERIC,
-    },
     {
         name: 'amiID',
         tooltip: 'creation.aws.ami.tooltip',
@@ -858,6 +851,15 @@ const awsPrivateControlData = [
         active: '',
         validation: VALIDATE_ALPHANUMERIC,
     },
+    {
+        name: 'Hosted Zone',
+        tooltip: 'creation.aws.hostedZone.tooltip',
+        id: 'hostedZone',
+        type: 'text',
+        placeholder: 'creation.aws.hostedZone.placeholder',
+        active: '',
+        validation: VALIDATE_ALPHANUMERIC,
+    },
     ///////////////////////  subnets  /////////////////////////////////////
     {
         id: 'privateLink',
