@@ -14,6 +14,7 @@ import {
     getWorkerName,
     isHidden_lt_OCP48,
     isHidden_SNO,
+    onChangeConnection,
     onChangeSNO,
     addSnoText,
 } from './ControlDataHelpers'
@@ -454,6 +455,8 @@ const setRegions = (control, controlData) => {
     } else {
         alterRegionData(controlData, regions, 'centralus')
     }
+
+    onChangeConnection(control, controlData)
 }
 
 const controlDataAZR = [
