@@ -27,36 +27,32 @@ export interface MenuProps extends Omit<React.HTMLAttributes<HTMLDivElement>, 'r
   ) => void;
   /** Accessibility label */
   'aria-label'?: string;
-  /** @beta Indicates if menu contains a flyout menu */
+  /** Indicates if menu contains a flyout menu */
   containsFlyout?: boolean;
-  /** @beta Indicates if menu contains a drilldown menu */
+  /** Indicates if menu contains a drilldown menu */
   containsDrilldown?: boolean;
-  /** @beta Indicates if a menu is drilled into */
+  /** Indicates if a menu is drilled into */
   isMenuDrilledIn?: boolean;
-  /** @beta Indicates the path of drilled in menu itemIds */
+  /** Indicates the path of drilled in menu itemIds */
   drilldownItemPath?: string[];
-  /** @beta Array of menus that are drilled in */
+  /** Array of menus that are drilled in */
   drilledInMenus?: string[];
-  /** @beta Callback for drilling into a submenu */
+  /** Callback for drilling into a submenu */
   onDrillIn?: (fromItemId: string, toItemId: string, itemId: string) => void;
-  /** @beta Callback for drilling out of a submenu */
+  /** Callback for drilling out of a submenu */
   onDrillOut?: (toItemId: string, itemId: string) => void;
-  /** @beta Callback for collecting menu heights */
+  /** Callback for collecting menu heights */
   onGetMenuHeight?: (menuId: string, height: number) => void;
-  /** @beta ID of parent menu for drilldown menus */
+  /** ID of parent menu for drilldown menus */
   parentMenu?: string;
-  /** @beta ID of the currently active menu for the drilldown variant */
+  /** ID of the currently active menu for the drilldown variant */
   activeMenu?: string;
-  /** @beta itemId of the currently active item. You can also specify isActive on the MenuItem. */
+  /** itemId of the currently active item. You can also specify isActive on the MenuItem. */
   activeItemId?: string | number;
   /** @hide Forwarded ref */
   innerRef?: React.Ref<HTMLDivElement>;
   /** Internal flag indicating if the Menu is the root of a menu tree */
   isRootMenu?: boolean;
-  /** Indicates if the menu should be without the outer box-shadow */
-  isPlain?: boolean;
-  /** Indicates if the menu should be srollable */
-  isScrollable?: boolean;
 }
 
 export interface MenuState {
@@ -74,9 +70,7 @@ class MenuBase extends React.Component<MenuProps, MenuState> {
   private activeMenu = null as Element;
   static defaultProps: MenuProps = {
     ouiaSafe: true,
-    isRootMenu: true,
-    isPlain: false,
-    isScrollable: false
+    isRootMenu: true
   };
 
   constructor(props: MenuProps) {
@@ -226,8 +220,6 @@ class MenuBase extends React.Component<MenuProps, MenuState> {
       containsFlyout,
       containsDrilldown,
       isMenuDrilledIn,
-      isPlain,
-      isScrollable,
       drilldownItemPath,
       drilledInMenus,
       onDrillIn,
@@ -259,8 +251,7 @@ class MenuBase extends React.Component<MenuProps, MenuState> {
           onGetMenuHeight,
           flyoutRef: this.state.flyoutRef,
           setFlyoutRef: flyoutRef => this.setState({ flyoutRef }),
-          disableHover: this.state.disableHover,
-          isScrollable
+          disableHover: this.state.disableHover
         }}
       >
         {isRootMenu && (
@@ -286,8 +277,6 @@ class MenuBase extends React.Component<MenuProps, MenuState> {
           id={id}
           className={css(
             styles.menu,
-            isPlain && styles.modifiers.plain,
-            isScrollable && styles.modifiers.scrollable,
             containsFlyout && styles.modifiers.flyout,
             containsDrilldown && styles.modifiers.drilldown,
             _isMenuDrilledIn && styles.modifiers.drilledIn,
