@@ -12,7 +12,7 @@ import { SelectMenu } from './SelectMenu';
 import { SelectOption, SelectOptionObject } from './SelectOption';
 import { SelectGroup, SelectGroupProps } from './SelectGroup';
 import { SelectToggle } from './SelectToggle';
-import { SelectContext, SelectVariant, SelectPosition, SelectDirection, KeyTypes } from './selectConstants';
+import { SelectContext, SelectVariant, SelectDirection, KeyTypes } from './selectConstants';
 import { Chip, ChipGroup, ChipGroupProps } from '../ChipGroup';
 import { Spinner } from '../Spinner';
 import {
@@ -46,8 +46,6 @@ export interface SelectProps
   children?: React.ReactElement[];
   /** Classes applied to the root of the Select */
   className?: string;
-  /** Indicates where menu will be aligned horizontally */
-  position?: SelectPosition | 'right' | 'left';
   /** Flag specifying which direction the Select menu expands */
   direction?: 'up' | 'down';
   /** Flag to indicate if select is open */
@@ -60,10 +58,6 @@ export interface SelectProps
   isDisabled?: boolean;
   /** Flag to indicate if the typeahead select allows new items */
   isCreatable?: boolean;
-  /** Flag indicating if placeholder styles should be applied */
-  hasPlaceholderStyle?: boolean;
-  /** @beta Flag indicating if the creatable option should set its value as a SelectOptionObject */
-  isCreateSelectOptionObject?: boolean;
   /** Value to indicate if the select is modified to show that validation state.
    * If set to success, select will be modified to indicate valid state.
    * If set to error, select will be modified to indicate error state.
@@ -144,7 +138,7 @@ export interface SelectProps
   chipGroupProps?: Omit<ChipGroupProps, 'children' | 'ref'>;
   /** Optional props to render custom chip group in the typeaheadmulti variant */
   chipGroupComponent?: React.ReactNode;
-  /** Flag for retaining keyboard-entered value in typeahead text field when focus leaves input away */
+  /** @beta Flag for retaining keyboard-entered value in typeahead text field when focus leaves input away */
   isInputValuePersisted?: boolean;
   /** Content rendered in the footer of the select menu */
   footer?: React.ReactNode;
@@ -177,14 +171,12 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
   static defaultProps: PickOptional<SelectProps> = {
     children: [] as React.ReactElement[],
     className: '',
-    position: SelectPosition.left,
     direction: SelectDirection.down,
     toggleId: null as string,
     isOpen: false,
     isGrouped: false,
     isPlain: false,
     isDisabled: false,
-    hasPlaceholderStyle: false,
     isCreatable: false,
     validated: 'default',
     'aria-label': '',
@@ -216,8 +208,7 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
     favoritesLabel: 'Favorites',
     ouiaSafe: true,
     chipGroupComponent: null,
-    isInputValuePersisted: false,
-    isCreateSelectOptionObject: false
+    isInputValuePersisted: false
   };
 
   state: SelectState = {
@@ -349,16 +340,7 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
   updateTypeAheadFilteredChildren = (typeaheadInputValue: string, e: React.ChangeEvent<HTMLInputElement> | null) => {
     let typeaheadFilteredChildren: any;
 
-    const {
-      onFilter,
-      isCreatable,
-      onCreateOption,
-      createText,
-      noResultsFoundText,
-      children,
-      isGrouped,
-      isCreateSelectOptionObject
-    } = this.props;
+    const { onFilter, isCreatable, onCreateOption, createText, noResultsFoundText, children, isGrouped } = this.props;
 
     if (onFilter) {
       /* The updateTypeAheadFilteredChildren callback is not only called on input changes but also when the children change.
@@ -426,37 +408,16 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
     if (typeaheadFilteredChildren.length === 0) {
       !isCreatable &&
         typeaheadFilteredChildren.push(
-          <SelectOption isDisabled key="no-results" value={noResultsFoundText} isNoResultsOption />
+          <SelectOption isDisabled key={0} value={noResultsFoundText} isNoResultsOption />
         );
     }
     if (isCreatable && typeaheadInputValue !== '') {
       const newValue = typeaheadInputValue;
-      if (
-        !typeaheadFilteredChildren.find(
-          (i: React.ReactElement) =>
-            i.props.value && i.props.value.toString().toLowerCase() === newValue.toString().toLowerCase()
-        )
-      ) {
-        const newOptionValue = isCreateSelectOptionObject
-          ? ({
-              toString: () => newValue,
-              compareTo: value =>
-                this.toString()
-                  .toLowerCase()
-                  .includes(value.toString().toLowerCase())
-            } as SelectOptionObject)
-          : newValue;
-
-        typeaheadFilteredChildren.push(
-          <SelectOption
-            key={`create ${newValue}`}
-            value={newOptionValue}
-            onClick={() => onCreateOption && onCreateOption(newValue)}
-          >
-            {createText} "{newValue}"
-          </SelectOption>
-        );
-      }
+      typeaheadFilteredChildren.push(
+        <SelectOption key={0} value={newValue} onClick={() => onCreateOption && onCreateOption(newValue)}>
+          {createText} "{newValue}"
+        </SelectOption>
+      );
     }
 
     this.setState({
@@ -745,7 +706,6 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
       isGrouped,
       isPlain,
       isDisabled,
-      hasPlaceholderStyle,
       validated,
       selections: selectionsProp,
       typeAheadAriaLabel,
@@ -786,7 +746,6 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
       favoritesLabel,
       footer,
       loadingVariant,
-      isCreateSelectOptionObject,
       ...props
     } = this.props;
     const {
@@ -798,11 +757,6 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
     } = this.state;
     const selectToggleId = toggleId || `pf-select-toggle-id-${currentId++}`;
     const selections = Array.isArray(selectionsProp) ? selectionsProp : [selectionsProp];
-    // Find out if the selected option is a placeholder
-    const selectedOption = React.Children.toArray(children).find(
-      (option: any) => option.props.value === selections[0]
-    ) as any;
-    const isSelectedPlaceholder = selectedOption && selectedOption.props.isPlaceholder;
     const hasAnySelections = Boolean(selections[0] && selections[0] !== '');
     const typeaheadActiveChild = this.getTypeaheadActiveChild(typeaheadCurrIndex);
     let childPlaceholderText = null as string;
@@ -1062,9 +1016,6 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
           {...(footer && { footerRef: this.footerRef })}
           isOpen={isOpen}
           isPlain={isPlain}
-          hasPlaceholderStyle={
-            hasPlaceholderStyle && (!selections.length || selections[0] === null || isSelectedPlaceholder)
-          }
           onToggle={this.onToggle}
           onEnter={this.onEnter}
           onClose={this.onClose}
