@@ -72,13 +72,13 @@ export const WizardToggle: React.FunctionComponent<WizardToggleProps> = ({
         aria-label={ariaLabel}
         aria-expanded={isNavOpen}
       >
-        <span className={css(styles.wizardToggleList)}>
-          <span className={css(styles.wizardToggleListItem)}>
+        <ol className={css(styles.wizardToggleList)}>
+          <li className={css(styles.wizardToggleListItem)}>
             <span className={css(styles.wizardToggleNum)}>{activeStepIndex}</span> {activeStepName}
             {activeStepSubName && <AngleRightIcon className={css(styles.wizardToggleSeparator)} aria-hidden="true" />}
-          </span>
-          {activeStepSubName && <span className={css(styles.wizardToggleListItem)}>{activeStepSubName}</span>}
-        </span>
+          </li>
+          {activeStepSubName && <li className={css(styles.wizardToggleListItem)}>{activeStepSubName}</li>}
+        </ol>
         <span className={css(styles.wizardToggleIcon)}>
           <CaretDownIcon aria-hidden="true" />
         </span>
